@@ -4,17 +4,17 @@ from typing import List
 import uuid
 import jpype
 import jpype.imports
-from jpype import _jcustomizer
+from jpype import _jcustomizer, _jclass
+
+TRUSTY_VERSION = "1.12.0.Final"
+CORE_DEPS = [
+    f"./dep/org/kie/kogito/explainability-core/{TRUSTY_VERSION}/*",
+    "./dep/org/slf4j/slf4j-api/1.7.30/slf4j-api-1.7.30.jar",
+    "./dep/org/apache/commons/commons-lang3/3.12.0/commons-lang3-3.12.0.jar",
+]
 
 
-def init(
-    *args,
-    path=[
-        "./dep/org/kie/kogito/explainability-core/1.5.0.Final/*",
-        "./dep/org/slf4j/slf4j-api/1.7.30/slf4j-api-1.7.30.jar",
-        "./dep/org/apache/commons/commons-lang3/3.8.1/commons-lang3-3.8.1.jar",
-    ],  # pylint: disable = line-too-long
-):
+def init(*args, path=CORE_DEPS):
     """Initialise Java binding"""
     # Launch the JVM
     try:
@@ -25,15 +25,14 @@ def init(
         if not Thread.isAttached:
             jpype.attachThreadToJVM()
 
-        from trustyai.utils import toJList
         from java.util import UUID
 
         @_jcustomizer.JConversion("java.util.List", exact=List)
-        def _JSequenceConvert(_, obj):
-            return toJList(obj)
+        def _JListConvert(_, py_list: List):
+            return _jclass.JClass("java.util.Arrays").asList(py_list)
 
         @_jcustomizer.JConversion("java.util.UUID", instanceof=uuid.UUID)
-        def _JSequenceConvert(_, obj):
+        def _JUUIDConvert(_, obj):
             return UUID.fromString(str(obj))
 
     except OSError:
